=============
API Reference
=============

This API reference details desmod's various modules, classes and
functions.

.. toctree::
   :maxdepth: 1

   desmod
   desmod.config
   desmod.component
   desmod.dot
   desmod.pool
   desmod.queue
   desmod.simulation
